# Table of Contents

- [applications-in-reference-catalog](<./applications-in-reference-catalog.md>)
- [SAP LeanIX](<./SAP-LeanIX.md>)
- [Applications in the Reference Catalog](<./Applications-in-the-Reference-Catalog.md>)
  - [Overview](<./Applications-in-the-Reference-Catalog/Overview.md>)
  - [Benefits](<./Applications-in-the-Reference-Catalog/Benefits.md>)
  - [Applications in Scope](<./Applications-in-the-Reference-Catalog/Applications-in-Scope.md>)
  - [Applications Out of Scope](<./Applications-in-the-Reference-Catalog/Applications-Out-of-Scope.md>)
  - [Configuring Settings for Syncing Fields and Establishing Relations](<./Applications-in-the-Reference-Catalog/Configuring-Settings-for-Syncing-Fields-and-Establishing-Relations.md>)
  - [Linking Applications to Catalog Items](<./Applications-in-the-Reference-Catalog/Linking-Applications-to-Catalog-Items.md>)
  - [Bulk Linking Application Fact Sheets](<./Applications-in-the-Reference-Catalog/Bulk-Linking-Application-Fact-Sheets.md>)
  - [Ignoring Application Fact Sheets](<./Applications-in-the-Reference-Catalog/Ignoring-Application-Fact-Sheets.md>)
  - [Changing the Link to a Different Item](<./Applications-in-the-Reference-Catalog/Changing-the-Link-to-a-Different-Item.md>)
  - [Linking an Application Fact Sheet from the Fact Sheet Page](<./Applications-in-the-Reference-Catalog/Linking-an-Application-Fact-Sheet-from-the-Fact-Sheet-Page.md>)
  - [Linking an Application Fact Sheet During Fact Sheet Creation](<./Applications-in-the-Reference-Catalog/Linking-an-Application-Fact-Sheet-During-Fact-Sheet-Creation.md>)
  - [Linking Multiple Applications to the Same Catalog Item](<./Applications-in-the-Reference-Catalog/Linking-Multiple-Applications-to-the-Same-Catalog-Item.md>)
  - [Aligned Catalog Items: Applications and IT Components](<./Applications-in-the-Reference-Catalog/Aligned-Catalog-Items-Applications-and-IT-Components.md>)
